pub struct NeoInteger(/* private fields */);Expand description
Neo N3 Integer type (arbitrary precision)
Implementations
Sourceimpl NeoInteger
impl NeoInteger
pub fn new<T: Into<BigInt>>(value: T) -> Self
pub fn zero() -> Self
pub fn one() -> Self
pub fn min_i32() -> Self
pub fn max_i32() -> Self
pub fn as_bigint(&self) -> &BigInt
Sourcepub fn try_as_i32(&self) -> Option<i32>
pub fn try_as_i32(&self) -> Option<i32>
Convert to i32, returning None if the value is out of range.
This is the safe alternative to as_i32() that doesn’t panic.
Sourcepub fn try_as_u32(&self) -> Option<u32>
pub fn try_as_u32(&self) -> Option<u32>
Convert to u32, returning None if the value is out of range.
This is the safe alternative to as_u32() that doesn’t panic.
Sourcepub fn as_i32_saturating(&self) -> i32
pub fn as_i32_saturating(&self) -> i32
Convert to i32, saturating at the boundaries if the value is out of range. This never panics.
Sourcepub fn as_u32_saturating(&self) -> u32
pub fn as_u32_saturating(&self) -> u32
Convert to u32, saturating at the boundaries if the value is out of range. This never panics.
Sourcepub fn as_i32(&self) -> i32
👎Deprecated since 0.4.1: Use try_as_i32() or as_i32_saturating() instead to avoid panics
pub fn as_i32(&self) -> i32
Convert to i32.
Panics
Panics if the value is outside the i32 range. Use try_as_i32() for a safe alternative.
Sourcepub fn as_u32(&self) -> u32
👎Deprecated since 0.4.1: Use try_as_u32() or as_u32_saturating() instead to avoid panics
pub fn as_u32(&self) -> u32
Convert to u32.
Panics
Panics if the value is outside the u32 range. Use try_as_u32() for a safe alternative.
pub fn to_i32(&self) -> Option<i32>
pub fn to_u32(&self) -> Option<u32>